@@ -19,10 +19,8 @@
 // <http://www.gnu.org/licenses/>.
 
 
-#include <vector>
+#define debug 0
+
+#include <debug/vector>
 
 // PR libstdc++/26142 global debug namespace clashes everywhere
-namespace debug
-{
-  int i;
-}
