@@ -17,21 +17,29 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// 27.6.1.3 unformatted input functions
+// The ARM simulator does not provide support for "fstat", which
+// causes "in_avail" to return an incorrect value.
+// { dg-do run { xfail arm*-*-elf arm*-*-eabi } }
+
+// C++98 27.6.1.3 unformatted input functions
+
+// { dg-require-fileio "" }
+// { dg-require-binary-io "" }
+// { dg-additional-files "istream_unformatted-1.tst" }
 
 #include <istream>
-#include <sstream>
+#include <fstream>
 #include <testsuite_hooks.h>
 
 // libstdc++/6746   
-void test12()
+void test13()
 {
   using namespace std;
   streamsize sum = 0;
-  istringstream iss("shamma shamma");
+  ifstream ifs("istream_unformatted-1.tst");
       
   // test01
-  size_t i = iss.rdbuf()->in_avail();
+  size_t i = ifs.rdbuf()->in_avail();
   VERIFY( i != 0 );
     
   // test02
@@ -39,16 +47,16 @@ void test12()
   do
     {
       char buf[1024];
-      extracted = iss.readsome(buf, sizeof buf);
+      extracted = ifs.readsome(buf, sizeof buf);
       sum += extracted;
     }
-  while (iss.good() && extracted);
+  while (ifs.good() && extracted);
   VERIFY( sum != 0 );  
 }
-
+ 
 int 
 main()
 {
-  test12();
+  test13();
   return 0;
 }
