@@ -1,4 +1,4 @@
-// 2003-02-26 Benjamin Kosnik <bkoz@redhat.com>
+// 2003-02-26  Carlo Wood  <carlo@alinoe.com>
 
 // Copyright (C) 2003-2025 Free Software Foundation, Inc.
 //
@@ -21,13 +21,17 @@
 
 #include <testsuite_hooks.h>
 
-// libstdc++/7986
+// c++/3111
 int main()
 {
   using namespace __gnu_test;
 
-  // cplus-dem FAIL  
-  verify_demangle("_Z1jM1AFivEPS1_", "j(int (A::*)(), int (A::**)())");
+  // cplus-dem FAIL
+  // icc FAIL
+  // verify_demangle("_Z1fAszL_ZZNK1N1A1fEvE3foo_0E_i", 
+  //       "f(int[sizeof(N::A::f() const::foo())])");
+  verify_demangle("_Z1fAszL_ZZNK1N1A1fEvE3foo_0E_i", 
+		  "f(int [sizeof (N::A::f() const::foo)])");
 
   return 0;
 }
